@@ -359,7 +359,7 @@ class ToLowerUrlRemovePipeline(
 #         return cls(ops)
 
 # Source: https://huggingface.co/sentence-transformers/all-MiniLM-L6-v2
-class MiniLMEmbeddingPipeline(Pipeline, id="mini-lm", summary="MiniLM Embedding", modalities=[DatasetModality.IMAGE]):
+class MiniLMEmbeddingPipeline(Pipeline, id="mini-lm", summary="MiniLM Embedding", modalities=[DatasetModality.TEXT]):
     """
     A pipeline that extracts sentence embeddings using a MiniLM model pre-trained on the 1B sentences.
     """
@@ -380,3 +380,12 @@ class MiniLMEmbeddingPipeline(Pipeline, id="mini-lm", summary="MiniLM Embedding"
 
         ops = [("embedding", FunctionTransformer(embedding_transform))]
         return cls(ops)
+
+
+class FlattenPipeline(sklearn.pipeline.Pipeline):
+    @staticmethod
+    def _flatten(X: np.ndarray) -> np.ndarray:
+        return np.reshape(X, newshape=(X.shape[0], -1))
+
+    def __init__(self):
+        super().__init__([("flatten", FunctionTransformer(FlattenPipeline._flatten))])
